##############################################################
# "cascript" Tcl script, VMD version 1.3 or higher recommended 
##############################################################

# Fit two structures and draw difference vector arrows between 
# carbon alphas.
#
# Usage:
#
# 1.) Edit procedure load below (correct the pdb file names)
# 2.) In VMD command console, type "source cascript" (this file)
# 3.) In VMD command console, type "load"
# 4.) In VMD command console, type "show"
#
# Tips:
# 
# 1.) To remove the arrows, type "draw delete all".
# 2.) To color the arrows differently (blue is default color),
#     type e.g. "draw color green" before 4.) above.
# 3.) To change the length or the orientation of the arrows, edit 
#     the rscale variable in procedure show.
# 4.) To change the thickness of the arrows, edit the raxis 
#     variable in procedure show.
# 5.) To customize the rendering of the protein structures, edit the
#     procedure load or use the VMD menus. E.g the vectors look better
#     if one conformation is turned off.
# 6.) For more info on VMD scripting see the URLs
#     http://www.ks.uiuc.edu/Research/vmd/script_library/ and
#     http://www.ks.uiuc.edu/Research/vmd/current/ug/node168.html
# 7.) The script library also has scripts for trajectory frame 
#     manipulation, so it is possible to write a script that shows 
#     the vectors dynamically for each trajectory frame, using the 
#     code below and in the library.
#
# Willy Wriggers, 6/4/99


proc load {} {
#   - Load the structures, select subset used for superposition
#     and for displaying difference vectors (here: carbon alphas)
#     and superimpose structures by Kabsch least squares fit.
#   - This procedure should be edited by the user and is called once 
#     at the beginning of a session.

    global all1 all2 ca1 ca2 mol1 mol2

    # load the first pdb file
    mol load pdb file1.pdb
    set mol1 [molinfo top]

    # load the second pdb file
    mol load pdb file2.pdb
    set mol2 [molinfo top]

    # customize the rendering of the molecules here 
    # (can be changed later with Graphics menu)
    mol delrep 0 $mol1
    mol representation Ribbons 0 6 3
    mol color ColorID 0 
    color change rgb 0 0.05 0.38 0.7
    mol selection {all}
    mol addrep $mol1
    mol delrep 0 $mol2
    mol representation Ribbons 0 6 3
    mol color ColorID 1
    mol selection {all}
    mol addrep $mol2
    draw color yellow

    set all1 [atomselect $mol1 all]
    $all1 global

    set all2 [atomselect $mol1 all]
    $all2 global

    # select the compared atoms in the first molecule 
    set ca1 [atomselect $mol1 "name CA"]
    $ca1 global

    # select the compared atoms in the second molecule 
    set ca2 [atomselect $mol2 "name CA"]
    $ca2 global

    # check input
    if {[$ca1 num] != [$ca2 num]} {
	error "load> two selections need same number of atoms!"
    }  
 
    # superimpose the two structures by compared atoms
    set t [measure fit $ca1 $ca2 weight mass]
    $all1 move $t
    puts "load> structures were superimposed."

    return
}

proc show {} {
#   - display the difference vectors (compared atoms) as arrows  

    global all1 all2 ca1 ca2 mol1 mol2
	
    # change this to make arrows shorter or longer 
    set rscale 1.0
    # change this to make arrows thicker or thinner 
    set raxis 0.3
    # change this to skip ca's between arrows
    set skip 0

    set coord1 [$ca1 get {x y z}]
    set coord2 [$ca2 get {x y z}]

    # loop through the two sets of coords
    set counter 0
    foreach c1 $coord1 c2 $coord2 {
	if {[expr (($counter/($skip+1))-($counter/($skip+1.0)))] == 0 } {
	    set cx2 [vecadd $c1 [vecscale [vecscale [vecsub $c2 $c1] $rscale] 0.7]]
	    set cx3 [vecadd $c1 [vecscale [vecsub $c2 $c1] $rscale]]
	    draw cylinder $c1 $cx2 radius $raxis resolution 11
	    draw cone $cx2 $cx3 radius [expr 2.5 * $raxis] resolution 16
	    draw sphere $c1 radius $raxis resolution 11
	}
	set counter [expr $counter + 1]
    }
    return
}






